/************************************************************
 * CurrentMap.h												*
 *  By Nicholas Crook										*
 *															*
 * Contains the map that has been currently loaded by the   *
 * game														*
 ************************************************************/

#ifndef CURRENTMAP_H
#define CURRENTMAP_H

#include "NDS.h"
#include "MathHelper.h"
#include "tilesheet.h"
#include "tilesheetMap.h"

class CurrentMap {
public:
	// Constructors
	CurrentMap();

	void InitializeMemory();						// Set up the memory for the tile maps
	void LoadTiles(int x, int y);					// Load the tiles around a given x and y (Based on tile coordinates not pixels)
	void FocusOn(int x, int y);						// Load the tiles around a given pixel x and y, will also set the screen offset to allow smooth transitions
	void SetOffset(int x, int y);					// Sets the offset for the loaded tiles
	void LoadMap(int mapId);						// Loads a given map from the maps in the pregenerated tilesheet.h header

	// Accessor functions
	inline int GetWidth() const {return m_Width;}
	inline int GetHeight() const {return m_Height;}
	inline int GetScreenTopLeftX() const {return m_MapX * 8 + m_OffsetX;}
	inline int GetScreenTopLeftY() const {return m_MapY * 8 + m_OffsetY;}
	inline u8* GetBounds() const {return m_Bounds;}

private:
	// State data to allow us to know what part of the map is currently loaded
	int m_MapX, m_MapY;

	/* State data to allow us to know what part of the loaded tiles is being displayed
	   Used to find the top left of the screen */
	int m_OffsetX, m_OffsetY;

	// Dimensions of the tile array
	int m_Width, m_Height;

	// The map data
	u16* m_Tiles;
	u8* m_Bounds;

	// The array to load tiles into 
	u16* m_MapMemory;
};

#endif