/************************************************************
 * Game.h													*
 *  By Nicholas Crook										*
 *															*
 * Contains the game logic and resource loading (excluding  *
 * the map) for this program								*
 ************************************************************/

#ifndef GAME_H
#define GAME_H

#include <nds.h>
#include <vector>
#include <stdio.h>
#include <time.h>
#include <maxmod9.h>

#include "font.h"
#include "SpriteSheet.h"
#include "Soundbank.h"
#include "Soundbank_bin.h"
#include "CurrentMap.h"
#include "Gizmo.h"
#include "Snail.h"
#include "Ring.h"

using namespace std;

// Allows us to track which state the game is currently in
enum GameState {
	TitleActive,
	GameActive,
	GameOverActive
};

class Game 
{
public:
	Game();									// Constructor

	void LoadMap(int map);					// Tells the game to load a new map 
	void Update();							// The game's update logic, occurs once per loop before the draw
	void Draw() const;						// The game's draw logic, occurs after an update and will update all displayed information
	void CleanMap();						// Cleans the map of all snails and rings, preping the game to load a different map
	void ResetStats();						// Resets the game stats that have occured up to this point
	void ResetGame();						// Resets the game to prepare the game for changing to the gameover state
	void SetGameState(GameState newState);	// Controls the loading and unloading of the background music loop

private:
	u8* m_SpriteSheetTiles;			// The sprite sheet for all sprites

	Gizmo m_Player;					// The player character
	vector<Snail> m_Snails;			// The enemy list
	vector<Ring> m_Rings;			// The ring list

	int m_CurrentMapNumber;			// Which map is currently being played
	CurrentMap m_Map;				// The map data for the map currently being played

	
	GameState m_GameState;					// The state the game is currently in
	bool m_Paused;							// Whether the game is currently paused
	int m_Score, m_CollectedRings, m_Lives;	// Game data

	int m_BG3, m_ConsoleAnimation;	// The console id and how far along in animation it is

	static const int MAP_COUNT = 4;	// The number of maps the game currently has
};

#endif