/************************************************************
 * GameObject.h												*
 *  By Nicholas Crook										*
 *															*
 * Contains location and direction information and the	    *
 * sprite object for game objects							*
 ************************************************************/

#ifndef GAMEOBJECT_H
#define GAMEOBJECT_H

#include <nds.h>
#include "Sprite.h"
#include "CurrentMap.h"

class GameObject {
public:
	// Constructors
	GameObject();
	GameObject(int x, int y, const Sprite sprite);

	void Clean() const;							// Tells the sprite object to clean itself from memory
	void Wipe() const;							// Tells the sprite object to remove itself from the screen
	void Draw(const CurrentMap* map) const;		// Draw the game object to the screen

	// Accessor functions to get private members
	inline int GetX() const { return m_X; }
	inline int GetY() const { return m_Y; }

	// Accessor function to update the lcoation and direction of a game object
	inline void MoveTo(int x, int y, int dx, int dy) {m_X = x; m_Y = y; m_DX = dx; m_DY = dy; }
protected:
	int m_X,m_Y, m_DX, m_DY;	// Contains location and direction information
	Sprite m_Sprite;			// Contains the graphics for this object
	bool m_Flipped;				// Contains whether the sprite will be flipped on draw
};
#endif