/************************************************************
 * Gizmo.h													*
 *  By Nicholas Crook										*
 *															*
 * Contains location and state information for the player's *
 * character, alse it contains the code to allow the player *
 * manipulate that character								*
 ************************************************************/

#ifndef GIZMO_H
#define GIZMO_H

#include <nds.h>
#include <maxmod9.h>
#include <math.h>

#include "GameObject.h"
#include "CurrentMap.h"
#include "MathHelper.h"

#include "Soundbank.h"

// Contains the different possible return states from the Update function
enum GizmoUpdateState {
	NormalUpdate,
	DiedUpdate,
	LevelClearUpdate
};

class Gizmo : public GameObject {
public:
	// Constructors
	Gizmo();
	Gizmo(int x, int y, const Sprite sprite);

	void Died();								// Set the variables for gizmos death
	void Jump();								// Set the variables for gizmo jumping
	GizmoUpdateState Update(CurrentMap* map);	// Update gizmo by reading input and doing collision detection

private:
	void CollisionCheckDiagonal(const CurrentMap* map);				// Check if the block we're currently in is causing a diagonal collision
	void CollisionCheckLeft(const CurrentMap* map);					// Check if the block we're walking into is causing a collision
	void CollisionCheckRight(const CurrentMap* map);				// Check if the block we're walking into is causing a collision
	void CollisionCheckUp(const CurrentMap* map);					// Check if the block we're jumping into is causing a collision
	void CollisionCheckDown(const CurrentMap* map, int speed);		// Check if the block we're on top of is causing a collision

	bool m_Jumping;				// If the gizmo game object is currently airborne
	int m_JumpAttempt;			// If the user has attempted to jump recently

	static const int JUMP_FRAMES_WINDOW = 10;	// How long after the user hits jump to wait and see if they land, if they do we'll jump again
};
#endif