/************************************************************
 * Snail.h													*
 *  By Nicholas Crook										*
 *															*
 * Contains location and state information for the snail	*
 * enemies, also it contains the code to check for			*
 * interactions with the player's character					*
 ************************************************************/

#ifndef SNAIL_H
#define SNAIL_H

#include <nds.h>
#include <math.h>

#include "GameObject.h"
#include "CurrentMap.h"
#include "Gizmo.h"
#include "Sprite.h"

// Return types for the collision check with the player's character
enum SnailCollisionState {
	NoCollision,
	SnailDiedCollision,
	GizmoDiedCollision
};

class Snail : public GameObject {
public:
	// Constructors
	Snail();
	Snail(int x, int y, Sprite sprite);

	bool Update(const CurrentMap* map);									// Updates the animations, aswell as tells the pathfinding algorithm to run, returns true when the snail is dead
	SnailCollisionState CollisionCheck(Gizmo* gizmo, CurrentMap* map);	// Checks if the snail has collided with gizmo and what type of collision it was
private:
	void Walk(const CurrentMap* map);									// Path finding algorithm to find the direction the snail should walk

	bool m_Dying;	// Controls the logic for update when the snail is dying
};
#endif