/************************************************************
 * Sprite.h													*
 *  By Nicholas Crook										*
 *															*
 * Contains the graphic components of game objects		    *
 ************************************************************/

#ifndef SPRITE_H
#define SPRITE_H

#include <nds.h>

// Contains a list of the different animations, also contains the location of the first sprite in that animation in the spritesheet
enum SpriteState { Gizmo_IdleAnimation = 0, Gizmo_WalkAnimation = 3, Gizmo_JumpAnimation = 8, Gizmo_DeathAnimation = 12, 
					BlueSnail_Walk = 16, BlueSnail_Death = 20, RedSnail_Walk = 24, RedSnail_Death = 28, Ring_Spin = 32};

class Sprite
{
public:
	// Constructors
	Sprite();
	Sprite(const u8* SpriteSheet, const SpriteState startingState, int id);

	void Clean() const;														// Cleans the Graphic data out of the video memory
	void Wipe() const;														// Removes a sprite from the screen, useful for when we're chaging game state
	void UpdateSprite();													// Tells the sprite to update its animation step using the current state
	void UpdateSprite(SpriteState newState);								// Tells the sprite to update its animation using the given state
	void UpdateSprite(SpriteState newState, int Frame);						// Tells the sprite to update its animation using the given state and frame
	void Draw(int x, int y, bool horizontalFlip) const;						// Draws the sprite on the screen

	// Accessor methods to get private members
	inline SpriteState GetCurrentState() const { return m_CurrentState; }
	inline int GetAnimationFrame() const { return m_AnimationFrame; }
private:
	void UpdateAnimation(int frame);								// Tells the sprite to update its animation frame
	int GetStepsForState(SpriteState state) const;					// Returns the number of frames a given state

	u16* m_SpriteCurrentFrame;						// Pointer to where we're storing this sprite in video ram
	u8* m_SpriteSheet;								// The sprite sheet we're loading from
	int m_Id;										// The Id of this sprite, used to control draw and free calls on the video ram
	SpriteState m_CurrentState;						// Which animation is currently being played
	int m_AnimationFrame;							// The current state of the animation
	
	static const int FRAMES_PER_STEP = 10;
	static const int SIZE_PER_FRAME = 32 * 32;
};
#endif