#include "Sprite.h"

// Constructors
Sprite::Sprite()
{
	m_SpriteCurrentFrame = oamAllocateGfx(&oamMain, SpriteSize_32x32, SpriteColorFormat_256Color);	
}

Sprite::Sprite(const u8* SpriteSheet, const SpriteState startingState, int id) :
m_SpriteSheet((u8*)SpriteSheet), m_Id(id), m_CurrentState(startingState), m_AnimationFrame(0)
{
	m_SpriteCurrentFrame = oamAllocateGfx(&oamMain, SpriteSize_32x32, SpriteColorFormat_256Color);	
}

// Cleans the Graphic data out of the video memory
void Sprite::Clean() const 
{
	oamFreeGfx(&oamMain, m_SpriteCurrentFrame);
	Wipe();
}

// Removes a sprite from the screen, useful for when we're chaging game state
void Sprite::Wipe() const 
{
	oamClear(&oamMain, m_Id, 1);
}

// Tells the sprite to update its animation step using the current state
void Sprite::UpdateSprite() 
{
	int oldFrame = m_AnimationFrame++;
	if (m_AnimationFrame / FRAMES_PER_STEP != oldFrame / FRAMES_PER_STEP) 
		UpdateAnimation((m_AnimationFrame >= GetStepsForState(m_CurrentState) * FRAMES_PER_STEP) ? 0 : m_AnimationFrame);
}

// Tells the sprite to update its animation using the given state
void Sprite::UpdateSprite(SpriteState newState)
{
	int oldFrame = m_AnimationFrame++;

	if (m_CurrentState != newState) {
		m_AnimationFrame = 0;
		m_CurrentState = newState;
	}

	if (m_AnimationFrame / FRAMES_PER_STEP != oldFrame / FRAMES_PER_STEP) 
		UpdateAnimation((m_AnimationFrame >= GetStepsForState(newState) * FRAMES_PER_STEP) ? 0 : m_AnimationFrame);
}

// Tells the sprite to update its animation using the given state and frame
void Sprite::UpdateSprite(SpriteState newState, int Frame)
{
	m_CurrentState = newState;
	if (m_AnimationFrame / FRAMES_PER_STEP != Frame) 
		UpdateAnimation(Frame * FRAMES_PER_STEP);
}

// Draws the sprite on the screen
void Sprite::Draw(int x, int y, bool horizontalFlip) const
{
	// If this sprite currently exists on screen we'll draw it, otherwise we'll remove it from the screen
	if ((x >= -32) && (x < 256) && (y >= -32) && (y < 192)) 
		oamSet(&oamMain, m_Id, x, y, 0, 0, SpriteSize_32x32, SpriteColorFormat_256Color, 
			m_SpriteCurrentFrame, -1, false, false, horizontalFlip, false, false);
	else
		Wipe();
}

// Tells the sprite to update its animation frame
void Sprite::UpdateAnimation(int frame)
{
	m_AnimationFrame = frame;
	u8* offset = m_SpriteSheet + (((int)m_CurrentState + frame / FRAMES_PER_STEP) * SIZE_PER_FRAME);
	dmaCopy(offset, m_SpriteCurrentFrame, 32*32);
}

// Returns the number of frames a given state
int Sprite::GetStepsForState(SpriteState state) const 
{
	switch(state) {
		case Gizmo_IdleAnimation:
			return 3;
		case Gizmo_WalkAnimation:
			return 5;
		default:
			return 4;
	}
}